package cmdlang

  1. Overview
  2. Docs

Module type Command.Enumerated_stringableSource

An interface for types that have a finite number of inhabitants that all have a canonical string representation.

type t
val all : t list
val to_string : t -> string

Due to the canonical string representation contract, cmdlang will assume to be able to define an equality function between ts defined as such:

  let equal a b = phys_equal a b || String.equal (to_string a) (to_string b)